@@ -1,10 +1,11 @@
 #coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client, formater, list2table, result_cache, sys_config
-from terminal import bold, magenta, gray, blue, green,red, yellow, confirm
+from ..util import client, formater, list2table, result_cache, it
+from terminal import bold, magenta, white, blue, green,red, yellow, confirm
+from ..const import CMD
 
-PROGRESS_LEN = 50
+PROGRESS_LEN = 70
 
 def all(clusterId=None):
     if clusterId:
@@ -35,17 +36,21 @@ def list():
 
     result_cache.save(arr, 'Id', 'clusters')
 
-    #print(gray('RequestId: %s' % result.get('RequestId')))
+    #print(white('RequestId: %s' % result.get('RequestId')))
     print('%s' % bold(magenta('Clusters:')))
     list2table.print_table(arr,['Id','Name',('State','State', formater.get_cluster_state),'Counts','CreationTime',('CreationTimeFromNow','FromNow')])
 
-    print(green('Total: %s' % result_len))
+    arrlen = len(arr)
+    cache_str =white('(cache %s %s)' %  (arrlen, 'rows' if arrlen>1 else 'row' ) )
+    print('%s %s' % ( green('Total: %s' % result_len), cache_str))
 
 
+    print(white('\n  type "%s c <Id|No.>" to show cluster detail\n' % (CMD)))
+
 def get(clusterId):
     clusterId = result_cache.get(clusterId, 'clusters')
 
-    print(gray('exec: bcs c %s' % clusterId))
+    print(white('exec: bcs c %s' % clusterId))
     result = client.get_cluster(clusterId)
 
     arr = [{
@@ -54,8 +59,9 @@ def get(clusterId):
         'c': '%s: %s' % (blue('State'), formater.get_cluster_state(result.get('State')))
     },{
         'a': '%s: %s' % (blue('ImageId'), result.get('ImageId')),
-        'b': '%s: %s' % (blue('Created'), formater.from_now(result.get('CreationTime'))),
-        'c': ''
+        #'b': '%s: %s' % (blue('InstanceType'),  result.get('InstanceType')),
+        'c': '',
+        'b': '%s: %s' % (blue('Created'), formater.from_now(result.get('CreationTime')))
     }]
     print('%s' % bold(magenta('Cluster:')))
     list2table.print_table(arr, ['a','b','c'], show_no=False, show_header=False)
@@ -66,8 +72,6 @@ def get(clusterId):
         print('%s: %s' % (blue('Description'), result.get('Description')))
 
 
-
-
     # groups
     groups = []
     total_desired_vm_count = 0
@@ -75,7 +79,7 @@ def get(clusterId):
         v = formater.to_dict(result.Groups[groupName])
         v['Name'] = groupName
         v['VMCount'] = '%s / %s' % (v['ActualVMCount'],v['DesiredVMCount'])
-        ins = sys_config.get_instance_type_resrc(v['InstanceType'])
+        ins = it.get_ins_type_map().get(v['InstanceType'])
         if ins:
             v['InstanceType/cpu/mem'] = '%s, %sCores, %sGB' % (v['InstanceType'], ins['cpu'], ins['memory'])
         else:
@@ -91,7 +95,7 @@ def get(clusterId):
     print(blue('Metrics:'))
     metrics = formater.to_dict(result.get('Metrics'))
     metrics['UnallocatedCount'] = total_desired_vm_count - metrics['StartingCount'] - metrics['RunningCount'] - metrics['StoppingCount'] - metrics['StoppedCount']
-    cols = [('Starting',blue), ('Running',green), ('Stopping',yellow), ('Stopped',red),('Unallocated',gray)]
+    cols = [('Starting',blue), ('Running',green), ('Stopping',yellow), ('Stopped',red),('Unallocated',white)]
     t = []
     p = []
 
@@ -104,15 +108,20 @@ def get(clusterId):
 
 
     # metric progress
-    print('  | %s |' % (''.join(p)) )
+    print(' | %s |' % (''.join(p)) )
 
+    # user data
+    ud = result.get('UserData')
+    if ud:
+        print('%s' % (blue('User Data:')))
+        for (k,v) in ud.items():
+            print('  %s : %s' % (k,v))
+
+    # OperationLogs
+    print('%s:\n  %s' % (blue('Operation Logs'),   '\n  '.join(result.get('OperationLogs')) ))
 
     # print groups
     print('%s' % bold(magenta('Groups:')))
     list2table.print_table(groups, ['Name','VMCount','InstanceType/cpu/mem', 'ResourceType'])
 
-
-    # description
-    print('%s:\n  %s' % (blue('OperationLogs'),   '\n  '.join(result.get('OperationLogs')) ))
-
     #print(result)
