@@ -1,19 +1,22 @@
 #coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client, isix, formater, list2table, result_cache, sys_config
-from terminal import bold, magenta, gray, blue, green,red, yellow, confirm
+from ..util import client, isix, formater, list2table, result_cache, it, config
+from terminal import bold, magenta, white, blue, green,red, yellow, confirm
 
 PROGRESS_LEN = 50
 
+
 def del_cluster(clusterId, yes=False):
     arr = clusterId.split(',')
+
     t = []
-
-
-    for item in arr:
-        id = result_cache.get(item, 'clusters')
-        t.append(id)
+    if config.isGod():
+        for item in arr:
+            id = result_cache.get(item, 'clusters')
+            t.append(id)
+    else:
+        t = arr
 
     if yes:
         for item in t:
@@ -29,6 +32,6 @@ def del_cluster(clusterId, yes=False):
 
 
 def __del_cluster(clusterId):
-    print(gray('exec: bcs delete_cluster %s' % clusterId))
+    print(white('exec: bcs delete_cluster %s' % clusterId))
     client.delete_cluster(clusterId)
     print(green('done'))
