@@ -1,7 +1,7 @@
 #coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client, result_cache
+from ..util import client, result_cache,config
 from terminal import confirm,green
 
 
@@ -11,8 +11,9 @@ def update(clusterId, groupName, nodes, yes=False):
     if v < 1:
         raise Exception('Invalid nodes, it should be a positive integer')
 
-    clusterId = result_cache.get(clusterId, 'clusters')
-    groupName = result_cache.get(groupName, 'groups')
+    if config.isGod():
+        clusterId = result_cache.get(clusterId, 'clusters')
+        groupName = result_cache.get(groupName, 'groups')
 
     if yes:
         client.change_cluster_vmcount(clusterId, groupName, nodes)
