@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 
 from ..util import client, oss_client, formater, list2table, result_cache, dag, util
-from terminal import bold, magenta, gray, blue, green, red, yellow, confirm
+from terminal import bold, magenta, white, blue, green, red, yellow, confirm
 from oss2.exceptions import NoSuchKey,NoSuchBucket
 from ..const import CMD
 
@@ -57,7 +57,7 @@ def list(num,all, state, jobId, jobName):
     if not all and num:
         arr = arr[:num]
 
-    print(gray('exec: bcs j -t %s%s' % ( num, ' '.join(tip) )))
+    print(white('exec: bcs j -t %s%s' % ( num, ' '.join(tip) )))
 
 
     for item in arr:
@@ -68,18 +68,21 @@ def list(num,all, state, jobId, jobName):
 
     print('%s' % bold(magenta('Jobs:')))
     list2table.print_table(arr, ['Id', 'Name', ('State', 'State', formater.get_job_state), 'Counts',
-                              ('CreationTimeFromNow', 'Created'), 'StartTime', 'EndTime','Elapse'])
-    print(green('Total: %s' % result_len))
+                              ('CreationTimeFromNow', 'Created'), 'StartTime', 'EndTime','Elapsed'])
+
+    cache_len = len(arr)
+    cache_str =white('(cache %s %s)' %  (cache_len, 'rows' if cache_len>1 else 'row' ) )
+    print('%s  %s' %(green('Total: %s' % result_len), cache_str) )
 
     if has_more:
-        print(gray('\n  append -t <num> to show more, or -a to show all\n'))
+        print(white('\n  append -t <num> to show more, or -a to show all\n'))
 
-    print(gray('  type "%s j <Id|No.>" to show job detail\n' % (CMD)))
+    print(white('  type "%s j <jobId|No.>" to show job detail\n' % (CMD)))
 
 def getJobDetail(jobId, descOnly):
     jobId = result_cache.get(jobId, 'jobs')
 
-    print(gray('exec: bcs j %s%s' % (jobId, ' -d' if descOnly else '')))
+    print(white('exec: bcs j %s%s' % (jobId, ' -d' if descOnly else '')))
 
     desc = client.get_job_description(jobId)
 
@@ -101,7 +104,7 @@ def getJobDetail(jobId, descOnly):
         "b": '%s: %s' % (blue('Type'), desc.get('Type')),
         "c": '%s: %s' % (blue('Priority'), desc.get('Priority'))
     }, {
-        "a": '%s: %s    %s: %s' % (blue('Created'), result.get('CreationTimeFromNow') ,blue('Elapse'), result.get('Elapse') ),
+        "a": '%s: %s    %s: %s' % (blue('Created'), result.get('CreationTimeFromNow') ,blue('Elapsed'), result.get('Elapsed') ),
         "b": '%s: %s' % (blue('StartTime'),  result.get('StartTime')),
         "c": '%s: %s' % (blue('EndTime'),  result.get('EndTime')),
     }]
@@ -112,17 +115,8 @@ def getJobDetail(jobId, descOnly):
 
 
     # description
-    if result.get('Description'):
-        print('  %s: %s' % (blue('Description'), result.get('Description') or ''))
-
-    # dag
-    print('%s' % bold(magenta('DAG:')))
-
-    deps = get_task_deps(desc.get('DAG'))
-
-    matric = dag.sortIndex(deps)
-
-    dag.draw(deps, matric)
+    if desc.get('Description'):
+        print('  %s: %s' % (blue('Description'), desc.get('Description') or ''))
 
 
     # task list
@@ -132,29 +126,41 @@ def getJobDetail(jobId, descOnly):
 
     arr = formater.format_date_in_arr(arr, ['StartTime', 'EndTime'])
 
+    # calc deps
+    deps = util.get_task_deps(desc.get('DAG'))
+    matric = dag.sortIndex(deps)
 
+    # dag
+    if len(arr)>1:
+        print('%s' % bold(magenta('DAG:')))
+        dag.draw(deps, matric)
+
+     # task list continue
     for item in arr:
         item['Counts'] = calc_metric_count(item['InstanceMetrics'])
         task_desc = desc.DAG.Tasks[item['TaskName']]
 
         item['Cluster'] = util.get_cluster_str(task_desc)
 
-    arr = sort_task_by_deps(arr, matric)
+    arr = util.sort_task_by_deps(arr, matric)
 
     # cache
     result_cache.save(arr, 'TaskName', 'tasks')
 
     print('%s' % bold(magenta('Tasks:')))
-    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime', 'Elapse','Cluster'])
+    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime', 'Elapsed','Cluster'])
 
+    arrlen = len(arr)
+    cache_str = white('(cache %s %s)' %  (arrlen, 'rows' if arrlen>1 else 'row' ) )
+    print(cache_str)
 
-    print(gray('\n  type "%s j <Id|No.> <TaskName|No.>" to show task detail\n' % CMD))
+    print(white('\n  type "%s j <jobId|No.> <taskName|No.>" to show task detail\n' % CMD))
 
 def getTaskDetail(jobId, taskName):
     jobId = result_cache.get(jobId, 'jobs')
     taskName = result_cache.get(taskName, 'tasks')
 
-    print(gray('exec: bcs j %s %s' %  (jobId,taskName) ))
+    print(white('exec: bcs j %s %s' %  (jobId,taskName) ))
 
     jobDesc = client.get_job_description(jobId)
 
@@ -172,7 +178,7 @@ def getTaskDetail(jobId, taskName):
 
     # task
     print('%s' % bold(magenta('Task:')))
-    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapse','Cluster'], show_no=False)
+    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapsed','Cluster'], show_no=False)
 
 
     # task description
@@ -180,7 +186,7 @@ def getTaskDetail(jobId, taskName):
 
     command = formater.to_dict(taskDesc.Parameters.Command)
 
-    print('%s: %s    %s: %s' %(  blue('Timeout'), taskDesc.Timeout, blue('MaxRetryCount'), taskDesc.MaxRetryCount))
+    print('%s: %s    %s: %s    %s: %s' %(  blue('Timeout'), taskDesc.Timeout, blue('MaxRetryCount'), taskDesc.MaxRetryCount, blue('WriteSupport'), taskDesc.WriteSupport, ))
 
     print(blue('Command:'))
     print('  %s: %s' % (blue('CommandLine') , command.get('CommandLine')))
@@ -220,23 +226,30 @@ def getTaskDetail(jobId, taskName):
 
     t = []
     c = 0
-    for ins in insts['Items']:
-        t.append('%s. %s(%s%%)' % (ins.get('InstanceId'), formater.get_job_state(ins.get('State')), ins.get('Progress')))
-        c += 1
-        if len(t)==5:
-            print('    '.join(t))
-            t=[]
-            c=0
-    if c>0:
-        print('    '.join(t))
+    if len(insts['Items']) > 10:
 
-    print(gray('\n  type "%s j <Id|No.> <TaskName|No.> <InstanceId>" to show instance detail\n' % CMD))
+        for ins in insts['Items']:
+            t.append('%s. %s(%s%%)' % (ins.get('InstanceId'), formater.get_job_state(ins.get('State')), ins.get('Progress')))
+            c += 1
+            if len(t)==5:
+                print('    '.join(t))
+                t=[]
+                c=0
+        if c>0:
+            print('    '.join(t))
+    else:
+        arr = formater.format_date_in_arr(insts['Items'], [ 'StartTime', 'EndTime'])
+        list2table.print_table(arr, ['InstanceId',('State', 'State', formater.get_job_state)
+                                     , ('Progress','Progress',lambda s:'%s%%' % s), 'RetryCount'
+            ,'StartTime','EndTime'],show_no=False)
+
+    print(white('\n  type "%s j <jobId|No.> <taskName|No.> <instanceId>" to show instance detail\n' % CMD))
 
 def getInstanceDetail(jobId, taskName, instanceId):
     jobId = result_cache.get(jobId, 'jobs')
     taskName = result_cache.get(taskName, 'tasks')
 
-    print(gray('exec: bcs j %s %s %s' %  (jobId,taskName, instanceId) ))
+    print(white('exec: bcs j %s %s %s' %  (jobId,taskName, instanceId) ))
 
     ins = client.get_instance(jobId, taskName, instanceId)
 
@@ -251,9 +264,12 @@ def getInstanceDetail(jobId, taskName, instanceId):
     print('%s: %s' % (blue('StdoutRedirectPath'), stdout_path ))
     print('%s: %s' % (blue('StderrRedirectPath'), stderr_path ))
 
-    if ins.Result.Detail:
+    if ins.Result and ins.Result.Detail:
         print('%s' % bold(magenta('Result:')))
-        print('%s' %  ins.Result.Detail )
+        print('  %s: %s' % (blue('ExitCode'), ins.Result.ExitCode ))
+        print('  %s: %s' % (blue('ErrorCode'), red(ins.Result.ErrorCode) ))
+        print('  %s: %s' % (blue('ErrorMessage'), red(ins.Result.ErrorMessage) ))
+        print('  %s: %s' % (blue('Detail'), red(ins.Result.Detail) ))
 
     try:
         showLog(ins.StderrRedirectPath,jobId,taskName, instanceId, 'stderr')
@@ -266,7 +282,7 @@ def getInstanceDetail(jobId, taskName, instanceId):
             if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
                 raise e
 
-    print(gray('\n  If you want to download these logs, type "%s log -h" for more\n' % CMD))
+    print(white('\n  If you want to download these logs, type "%s log -h" for more\n' % CMD))
 
 def showLog(osspath, jobId, taskName, instanceId, logType):
 
@@ -307,27 +323,4 @@ def sort_job_list(arr):
 
     return unfinished_arr + finished_arr
 
-def sort_task_by_deps(arr, matric):
-    m = {}
-    for n in arr:
-        m[n['TaskName']]=n
 
-    t=[]
-    for items in matric:
-        for taskname in items:
-            t.append(m[taskname])
-    return t
-
-def get_task_deps(dag):
-    deps = dag.get('Dependencies') or {}
-    tasks = dag.get('Tasks')
-
-    m = {}
-    for k in tasks:
-        m[k] = []
-
-    for k in m:
-        if not deps.get(k):
-            deps[k] = []
-
-    return deps
