@@ -1,19 +1,22 @@
 #coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client, isix, formater, list2table, result_cache, sys_config
-from terminal import bold, magenta, gray, blue, green,red, yellow, confirm
+from ..util import client,config,result_cache
+from terminal import bold, magenta, white, blue, green,red, yellow, confirm
 
 PROGRESS_LEN = 50
 
 def restart_job(jobId, yes=False):
     arr = jobId.split(',')
+
+
     t = []
-
-
-    for item in arr:
-        id = result_cache.get(item, 'jobs')
-        t.append(id)
+    if config.isGod():
+        for item in arr:
+            id = result_cache.get(item, 'jobs')
+            t.append(id)
+    else:
+        t = arr
 
     if yes:
         for item in t:
@@ -29,6 +32,6 @@ def restart_job(jobId, yes=False):
 
 
 def __restart_job(jobId):
-    print(gray('exec: bcs restart_job %s' % jobId))
+    print(white('exec: bcs restart_job %s' % jobId))
     client.start_job(jobId)
     print(green('done'))
