@@ -11,7 +11,7 @@ def update(jobId, priority=-1, yes=False):
     if v < 1 or v > 1000:
         raise Exception('Invalid priority, it should be in scope [1..1000]')
 
-    jobId = result_cache.get(jobId, 'jobs')
+    #jobId = result_cache.get(jobId, 'jobs')
 
 
     if yes:
