@@ -1,11 +1,12 @@
 import os
-from ..util import client, zip,oss_client
+from ..util import client, zip,oss_client,config
 from ..const import IMG_ID,INS_TYPE
-from terminal import green,gray
+from terminal import green,white
 import re
 import json
 import tarfile
 from batchcompute_cli.const import CMD
+import shutil
 
 def create(project_name, location=None, type='empty',job=None ):
 
@@ -53,18 +54,21 @@ def create(project_name, location=None, type='empty',job=None ):
 
         zip.unzip_file('%s.zip' % src, dist)
 
+        if type=='empty' or type=='python':
+            # add oss2 to src
+            add_oss2(cur_path, dist)
+
         # update job.json set imageId: m-28sm4m6ez
         update_image_n_instype(os.path.join(dist,'job.json'))
 
     print(green('Done'))
-    print(gray('Type "cd %s && %s p st" to show project detail\n' % (project_name,CMD)))
+    print(white('Type "cd %s && %s p st" to show project detail\n' % (project_name,CMD)))
 
 def update_image_n_instype(p):
     obj = {}
     with open(p, 'r') as f:
         obj = json.loads(f.read())
 
-
     with open(p, 'w') as f:
         ts = obj['DAG']['Tasks']
         for k in ts:
@@ -82,6 +86,11 @@ def download_worker(packageUri, dist):
     with tarfile.open(tarpath, 'r|gz') as f:
         f.extractall(src)
 
+def add_oss2(cur_path, dist):
+    src = os.path.join(cur_path, '../lib/oss2')
+    target = os.path.join(dist,'src/oss2')
+    shutil.copytree(src, target, True)
+
 
 def transform_job_id(job=None):
     if not job or not job.startswith('job-'):
