@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from ..const import *
 
 
@@ -15,6 +16,13 @@ def getJSON():
                 "locale": 'set locale, scope:[zh_CN|en]'
             }
         },
+        'info': {
+            "description": "show information of batchcompute-cli",
+            "latest_version": "Latest version",
+            "current_version": "Current version",
+            "has_upgrade": "Type 'pip install -U batchcompute-cli' to upgrade",
+            "has_upgrade2":  "If fails with permission deny, try 'sudo pip install -U batchcompute-cli'"
+        },
         "instance_type": {
             "description": 'show instance type list.'
         },
@@ -33,18 +41,22 @@ def getJSON():
             }
         },
         'log': {
-            'description': 'download log from oss to local directory',
+            'description': 'print logs, or download them from oss to local directory',
             'option': {
-                'dir_path': 'directory path to save logs, default: ./logs/'
+                'dir_path': 'directory path to save logs, if your don\'t set this option, just print logs',
+                'stderr': 'show stderr log only',
+                'stdout': 'show stdout log only'
             }
         },
         'create_cluster': {
             'description': 'create cluster',
             'option': {
-                'imageId': "required, ECS Image Id",
-                'groups': "optional, groupInfo, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
+                'image': "optional, imageId, default: %s" % IMG_ID,
+                'type': "optional, instanceType, type '%s it' for more, default: %s" % (CMD, INS_TYPE),
+                'nodes': "optional, int, default: 1",
+                #'groups': "optional, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
                 'description': "optional, description, string",
-                'userDatas': "optional, user data, k=v pairs"
+                'userData': "optional, user data k-v pairs, exp: a:b,c:e"
             }
         },
         'delete_cluster': {
@@ -95,22 +107,40 @@ def getJSON():
             'description': 'submit a single task job quickly',
             'option': {
                 'cluster': """optional, should be a cluster_id, or an auto_cluster string.
-                                 default value is an auto_cluster string: img=%s:type=%s.
-                                 you can use a exists cluster(type '%s c' for more cluster id),
-                                 or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """ % (
+                                      default value is an auto_cluster string: img=%s:type=%s.
+                                      you can use a exists cluster(type '%s c' for more cluster id),
+                                      or use auto cluster, format: img=<imageId>:type=<instanceType>
+                                      (instanceType default: %s, type '%s it' for more instanceType). """ % (
                 IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
-                'pack': "pack the files in the program_folder into worker.tar.gz, and upload to oss, if you didn't set this option, no pack, no upload",
-                'timeout': "job would failed if it had expired, default: 172800(2 days)",
-                'nodes': "the number of machines you needed to run the program, default: 1",
-                'force': "job don't fail when instance were failed, default: job fail when even one instance were failed",
-                'env': "set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
-                'read_mount': "mount a oss path to local file system in read-only mode, kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...], example: oss://bucket/key:/home/admin/ossdir ",
-                'write_mount': "mount a oss path to local file system in writable mode(files in the mounted folder will be upload to oss_path after the task is finished), kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...], example: oss://bucket/key:/home/admin/ossdir ",
-                'mount': "mount a oss path to local file system in read/write mode, kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...], example: oss://bucket/key:/home/admin/ossdir "
+                'pack': "optional,pack the files in the program_folder into worker.tar.gz, and upload to oss, if you don't set this option, no pack, no upload",
+                'priority': 'optional,int,job priority,default:0\n',
+                'timeout': "optional,job would failed if it had expired, default: 172800(2 days)",
+                'nodes': "optional,the number of machines you needed to run the program, default: 1",
+                'description': 'optional,set job description',
+                'force': "optional,job don't fail when instance were failed, default: job fail when even one instance were failed",
+                'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
+                'read_mount': """optional,mount a oss path to local file system in read-only mode, kv-pairs, multi-supported,
+                                      format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
+                                      example: oss://bucket/key:/home/admin/ossdir """,
+                'write_mount': """optional,mount a oss path to local file system in writable mode
+                                      (files in the mounted folder will be upload to oss_path after the task is finished),
+                                      kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
+                                      example: oss://bucket/key:/home/admin/ossdir """,
+                'mount': """optional,mount a oss path to local file system in read/write mode, kv-pairs, multi-supported,
+                                      format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
+                                      example: oss://bucket/key:/home/admin/ossdir """,
+                'docker': """optional,optional, use docker, format: <docker_image_name>@<docker_storage_oss_path>,
+                                      example: localhost:5000/myubuntu@oss://bucket/dockers/
+                                      or for short: myubuntu@oss://bucket/dockers/ """,
+                'file': """optional,submit job from a config file, if you give options explicitly, options from this file will be override""",
+                'show_json': 'optional,just output job.json, don\'t submit a job, default: false'
             }
         },
+        'check': {
+            'description': "check job status and failed reasons"
+        },
         'project': {
-            'description': 'project commanders: init, create, build, submit, etc.',
+            'description': 'project commanders: create, build, submit, etc.',
             'create': {
                 'description': 'create a job project',
                 'option': {
@@ -126,9 +156,10 @@ def getJSON():
                 'description': 'update job.json',
                 'option': {
                     'cluster': """optional, should be a cluster_id, or an auto_cluster string.
-                                 default value is an auto_cluster string: img=%s:type=%s.
-                                 you can use a exists cluster(type '%s c' for more cluster id),
-                                 or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """
+                              default value is an auto_cluster string: img=%s:type=%s.
+                              you can use a exists cluster(type '%s c' for more cluster id),
+                              or use auto cluster, format: img=<imageId>:type=<instanceType>
+                              (instanceType default: %s, type '%s it' for more instanceType). """
                     % (IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
                     "docker": """optional, use docker image to run, format:<oss_docker_storage_path>:<docker_name>"""
                 }
@@ -154,21 +185,34 @@ def getJSON():
             }
         },
         'oss': {
-            'description': 'oss commanders: upload, download, mkdir, ls, etc.',
+            'description': 'oss commanders: upload, download, ls, etc.',
             'pwd': {
                 'description': 'show current osspath',
             },
-            'upload': {
-                'description': 'upload file or directory to oss, support wildcards *',
+            'ls': {
+                'description': 'show folders and files in an osspath',
                 'option': {
-                    'recursion': "upload directory and the entire subtree to oss"
+                    'name': 'search by name',
+                    'top': 'length of result-set to show',
                 }
             },
+            'cat': {
+                'description': 'print oss file content',
+            },
+            'upload': {
+                'description': 'upload file or directory to oss'
+            },
             'download': {
                 'description': 'download file or directory from oss',
                 'option': {
                     'recursion': "download directory and the entire subtree from oss"
                 }
+            },
+            'delete': {
+                'description': 'delete file or directory from oos',
+                'option': {
+                    'yes': 'delete in silent mode'
+                 }
             }
         }
     }
