@@ -2,9 +2,10 @@ import datetime
 import calendar
 import time
 from ..util.isix import STRING
-from terminal import green, gray, red, yellow, cyan
+from terminal import green, white, red, yellow, cyan
 import os
 import re
+import math
 
 
 def get_cluster_state(state):
@@ -14,7 +15,7 @@ def get_cluster_state(state):
     elif s=='deleting':
         return red(state)
     else:
-        return gray(state)
+        return white(state)
 
 def get_job_state(state):
     s = state.lower() if state else state
@@ -23,13 +24,13 @@ def get_job_state(state):
     if s=='finished':
         return green(state)
     elif s=='waiting':
-        return gray(state)
+        return white(state)
     elif s=='failed':
         return red(state)
     elif s=='stopped':
         return yellow(state)
     else:
-        return gray(state)
+        return white(state)
 
 def filter_list(arr, filters):
     '''
@@ -84,7 +85,7 @@ def format_date_in_arr(arr, cols):
     t=[]
     for m in arr:
         if 'StartTime' in cols and 'EndTime' in cols:
-            m['Elapse'] = calc_elapse(m.get('StartTime'), m.get('EndTime'))
+            m['Elapsed'] = calc_elapse(m.get('StartTime'), m.get('EndTime'))
 
         for k in cols:
             v = m.get(k)
@@ -92,7 +93,7 @@ def format_date_in_arr(arr, cols):
                 m[k] = format_datetime(v)
                 m['%sFromNow' % k] = from_now(v)
             else:
-                m[k] = '-'
+                m[k] = 'null'
         t.append(m)
     return t
 
@@ -103,7 +104,7 @@ def format_datetime(dt):
     elif isinstance(dt, STRING):
         return format_date_str(dt)
     else:
-        return dt or '-'
+        return dt or 'null'
 
 def format_date_str(s):
     if not s:
@@ -177,4 +178,20 @@ def calc_elapse(start, end):
     if start and end:
         return '%ds' % int(time.mktime(end.timetuple()) - time.mktime(start.timetuple()))
     else:
-        return ''
\ No newline at end of file
+        return ''
+
+def format_size(s):
+    if s > (1024*1024*1024*1024):
+        v = int(s/(1024*1024*1024*1024))
+        return '%sTB' % v
+    if s > 1024*1024*1024:
+        v = int(s/(1024*1024*1024))
+        return '%sGB' % v
+    if s > 1024*1024:
+        v = int(s/1024/1024)
+        print(s)
+        return '%sMB' % v
+    if s > 1024:
+        v = int(s/1024)
+        return '%skB' % v
+    return '%sB' % s
\ No newline at end of file
